@@ -9,7 +9,6 @@ import re
 from time import gmtime, strftime
 from datetime import datetime, date, timedelta
 import yaml
-from influxdb import InfluxDBClient
 import psycopg2
 import click
 from fdsnextender import FdsnExtender
@@ -68,6 +67,9 @@ def scan_volumes(volumes):
             if 'type' in volume:
                 for s in stats:
                     s['type'] = volume['type']
+            if 'name' in volume:
+                for s in stats:
+                    s['volume'] = volume['name']
             volume_stats.append(stats)
             # If a type of data was specified, then we add this tag to the stats
         else:
@@ -157,61 +159,12 @@ def cli(configfile, force_scan, dryrun, verbose):
         for stat in statistics:
             cur.execute(
                 """
-                INSERT INTO dataholdings (network, year, station, channel, quality, type, size, is_permanent, date)
-                VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s)
+                INSERT INTO dataholdings (network, year, station, channel, quality, type, size, is_permanent, volume, date)
+                VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
                 ON CONFLICT (network,year,station,channel,type,date) DO UPDATE SET size = EXCLUDED.size;
                 """,
-                (stat['network'], stat['year'], stat['station'], stat['channel'], stat['quality'], stat['type'], stat['size'], stat['is_permanent'], stat['date']))
+                (stat['network'], stat['year'], stat['station'], stat['channel'], stat['quality'], stat['type'], stat['size'], stat['is_permanent'], stat['volume'], stat['date']))
         conn.commit()
 
-    if 'influxdb' in cfg:
-        logger.info('Writing in influxdb')
-        influxdb_json_data = []
-        # Compose json data
-        record_time = strftime("%Y-%m-%dT%H:%M:%SZ", gmtime())
-        for stat in statistics:
-            influxdb_json_data.append(
-                {"measurement": cfg['influxdb']['measurement'],
-                 "tags": {
-                     "year": int(stat['year']),
-                     "network": stat['network'],
-                     "station": stat['station'],
-                     "channel": stat['channel'],
-                     "quality": stat['quality'],
-                     "permanent": bool(stat['is_permanent']),
-                     "type": stat['type'],
-                     "date": stat['date']
-                 },
-                 "time": record_time,
-                 "fields": {
-                     "size": int(stat['size'])
-                 }
-                }
-            )
-        logger.info(influxdb_json_data)
-
-        # Now, send this data to influxdb
-        try:
-            logger.info("Sending data to influxdb")
-
-            logger.debug("host     = %s", cfg['influxdb']['server'])
-            logger.debug("port     = %s", str(cfg['influxdb']['port']))
-            logger.debug("database = %s", cfg['influxdb']['database'])
-            logger.debug("username = %s", cfg['influxdb']['user'])
-
-            client = InfluxDBClient(host=cfg['influxdb']['server'],
-                                    port=cfg['influxdb']['port'],
-                                    database=cfg['influxdb']['database'],
-                                    username=cfg['influxdb']['user'],
-                                    password=cfg['influxdb']['password'],
-                                    ssl=cfg['influxdb']['ssl'],
-                                    verify_ssl=cfg['influxdb']['verify_ssl']
-                                    )
-
-            client.write_points(influxdb_json_data)
-        except Exception as e:
-            logger.error("Unexpected error writing data to influxdb")
-            logger.error(e)
-
 if __name__ == "__main__":
     cli()
